==> react-molecule-autosuggest-2.48.0.tgz: package/lib/AutoSuggest.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoClose", "children", "disabled", "errorState", "id", "isOpen", "keysCloseList", "keysSelection", "multiselection", "onBlur", "onChange", "onClear", "onEnter", "onFocus", "onSelect", "onToggle", "refMoleculeAutosuggest", "refMoleculeAutosuggestInput", "state"];
import { Children, createRef, cloneElement, useRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { inputTypes } from '@s-ui/react-atom-input';
import MoleculeAutosuggestSingleSelection from './components/SingleSelection';
import MoleculeAutosuggestMultipleSelection from './components/MultipleSelection';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
import { BASE_CLASS, CLASS_FOCUS, CLASS_DISABLED, AUTOSUGGEST_STATES, CLOSE_KEYS_LIST, SELECT_KEYS_LIST, getIsTypeableKey } from './config';
import { jsx as _jsx } from "react/jsx-runtime";

var MoleculeAutosuggest = function MoleculeAutosuggest(_ref) {
  var _cx;

  var _ref$autoClose = _ref.autoClose,
      autoClose = _ref$autoClose === void 0 ? true : _ref$autoClose,
      children = _ref.children,
      disabled = _ref.disabled,
      errorState = _ref.errorState,
      _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      isOpen = _ref.isOpen,
      _ref$keysCloseList = _ref.keysCloseList,
      keysCloseList = _ref$keysCloseList === void 0 ? CLOSE_KEYS_LIST : _ref$keysCloseList,
      _ref$keysSelection = _ref.keysSelection,
      keysSelection = _ref$keysSelection === void 0 ? SELECT_KEYS_LIST : _ref$keysSelection,
      multiselection = _ref.multiselection,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? function () {} : _ref$onBlur,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$onClear = _ref.onClear,
      onClear = _ref$onClear === void 0 ? function () {} : _ref$onClear,
      _ref$onEnter = _ref.onEnter,
      onEnter = _ref$onEnter === void 0 ? function () {} : _ref$onEnter,
      _ref$onFocus = _ref.onFocus,
      onFocus = _ref$onFocus === void 0 ? function () {} : _ref$onFocus,
      _ref$onSelect = _ref.onSelect,
      onSelect = _ref$onSelect === void 0 ? function () {} : _ref$onSelect,
      _ref$onToggle = _ref.onToggle,
      onToggle = _ref$onToggle === void 0 ? function () {} : _ref$onToggle,
      _ref$refMoleculeAutos = _ref.refMoleculeAutosuggest,
      refMoleculeAutosuggestFromProps = _ref$refMoleculeAutos === void 0 ? {} : _ref$refMoleculeAutos,
      _ref$refMoleculeAutos2 = _ref.refMoleculeAutosuggestInput,
      refMoleculeAutosuggestInputFromProps = _ref$refMoleculeAutos2 === void 0 ? {} : _ref$refMoleculeAutos2,
      state = _ref.state,
      restProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var innerRefMoleculeAutosuggest = useRef();
  var refMoleculeAutosuggest = useMergeRefs(innerRefMoleculeAutosuggest, refMoleculeAutosuggestFromProps);

  var _useState = useState(isOpen),
      isOpenState = _useState[0],
      setOpenState = _useState[1];

  useEffect(function () {
    setOpenState(isOpen);
  }, [isOpen, setOpenState]);
  var refsMoleculeAutosuggestOptions = useRef([]);
  var innerRefMoleculeAutosuggestInput = useRef();
  var refMoleculeAutosuggestInput = useMergeRefs(innerRefMoleculeAutosuggestInput, refMoleculeAutosuggestInputFromProps);

  var _useState2 = useState(false),
      focus = _useState2[0],
      setFocus = _useState2[1];

  var handleToggle = function handleToggle(event, _ref2) {
    var isOpen = _ref2.isOpen;
    setOpenState(isOpen === undefined ? !isOpenState : !!isOpen);
    typeof onToggle === 'function' && onToggle(event, {
      isOpen: isOpen
    });
  };

  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeAutosuggestOptions.current[index] = /*#__PURE__*/createRef();
    return /*#__PURE__*/cloneElement(child, {
      innerRef: refsMoleculeAutosuggestOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + AUTOSUGGEST_STATES.ERROR, errorState === false && BASE_CLASS + "--" + AUTOSUGGEST_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx));

  var closeList = function closeList(ev) {
    var domMoleculeAutosuggest = innerRefMoleculeAutosuggest.current;
    handleToggle(ev, {
      isOpen: false
    });
    if (multiselection) onChange(ev, {
      value: ''
    });
    domMoleculeAutosuggest && !focus && domMoleculeAutosuggest.focus();
    setFocus(false);
    ev.preventDefault();
    ev.stopPropagation();
  };

  var focusFirstOption = function focusFirstOption(ev, _ref3) {
    var options = _ref3.options;
    if (options[0]) options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var innerRefInput = innerRefMoleculeAutosuggestInput.current;
    var key = ev.key;
    var options = optionsFromRef.map(getTarget);
    var isTypeableKey = getIsTypeableKey(key);
    var isSelectionKey = keysSelection.includes(key);

    if (isTypeableKey) {
      if (!isSelectionKey) domInnerInput.focus();
    }

    if (isOpenState) {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      if (keysCloseList.includes(key)) closeList(ev);else if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });else if (isSomeOptionFocused) handleFocusIn(ev);

      if (key === 'Enter') {
        onEnter(ev);
        innerRefInput && innerRefInput.focus();
      }
    }
  };

  var handleFocusIn = function handleFocusIn(ev) {
    onFocus(ev);
    setFocus(true);
  };

  var handleFocusOut = function handleFocusOut(ev) {
    ev.persist();
    var domContainer = innerRefMoleculeAutosuggest.current;
    var domInnerInput = innerRefMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var options = optionsFromRef.map(getTarget);
    setTimeout(function () {
      var currentElementFocused = getCurrentElementFocused();
      var focusOutFromOutside = ![domInnerInput].concat(options).includes(currentElementFocused) && !domContainer.contains(currentElementFocused);

      if (focusOutFromOutside) {
        if (autoClose && isOpenState) {
          closeList(ev);
        } else {
          setFocus(false);
          onBlur();
        }
      }
    }, 1);
    setFocus(true);
  };

  var handleInputKeyDown = function handleInputKeyDown(ev) {
    var key = ev.key;
    if (key !== 'ArrowDown') ev.stopPropagation();

    if (key === 'Enter') {
      onEnter(ev);
      onEnter && autoClose && closeList(ev);
    }
  };

  var handleClick = function handleClick() {
    var innerRefInput = innerRefMoleculeAutosuggestInput.current;
    innerRefInput && innerRefInput.focus();
  };

  var autosuggestSelectionProps = _extends({
    autoClose: autoClose,
    children: extendedChildren,
    disabled: disabled,
    errorState: errorState,
    id: id,
    innerRefInput: refMoleculeAutosuggestInput,
    isOpen: isOpenState,
    keysCloseList: keysCloseList,
    keysSelection: keysSelection,
    onBlur: onBlur,
    onChange: onChange,
    onClear: onClear,
    onEnter: onEnter,
    onFocus: onFocus,
    onInputKeyDown: handleInputKeyDown,
    onKeyDown: handleKeyDown,
    onSelect: onSelect,
    onToggle: handleToggle,
    state: state
  }, restProps);

  var AutosuggestSelection = multiselection ? MoleculeAutosuggestMultipleSelection : MoleculeAutosuggestSingleSelection;
  return /*#__PURE__*/_jsx("div", {
    ref: refMoleculeAutosuggest,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut,
    onClick: handleClick,
    role: "combobox",
    "aria-controls": id,
    "aria-expanded": isOpenState,
    children: /*#__PURE__*/_jsx(AutosuggestSelection, _extends({}, autosuggestSelectionProps))
  });
};

MoleculeAutosuggest.displayName = 'MoleculeAutosuggest';
export default MoleculeAutosuggest;

==> react-molecule-autosuggest-2.50.0.tgz: package/lib/AutoSuggest.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoClose", "children", "disabled", "errorState", "id", "isOpen", "keysCloseList", "keysSelection", "multiselection", "onBlur", "onChange", "onClear", "onEnter", "onFocus", "onSelect", "onToggle", "refMoleculeAutosuggest", "refMoleculeAutosuggestInput", "state"];
import { Children, createRef, cloneElement, useRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { inputTypes } from '@s-ui/react-atom-input';
import MoleculeAutosuggestSingleSelection from './components/SingleSelection';
import MoleculeAutosuggestMultipleSelection from './components/MultipleSelection';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
import { BASE_CLASS, CLASS_DISABLED, AUTOSUGGEST_STATES, CLOSE_KEYS_LIST, SELECT_KEYS_LIST, getIsTypeableKey } from './config';
import { jsx as _jsx } from "react/jsx-runtime";

var MoleculeAutosuggest = function MoleculeAutosuggest(_ref) {
  var _cx;

  var _ref$autoClose = _ref.autoClose,
      autoClose = _ref$autoClose === void 0 ? true : _ref$autoClose,
      children = _ref.children,
      disabled = _ref.disabled,
      errorState = _ref.errorState,
      _ref$id = _ref.id,
      id = _ref$id === void 0 ? '' : _ref$id,
      isOpen = _ref.isOpen,
      _ref$keysCloseList = _ref.keysCloseList,
      keysCloseList = _ref$keysCloseList === void 0 ? CLOSE_KEYS_LIST : _ref$keysCloseList,
      _ref$keysSelection = _ref.keysSelection,
      keysSelection = _ref$keysSelection === void 0 ? SELECT_KEYS_LIST : _ref$keysSelection,
      multiselection = _ref.multiselection,
      _ref$onBlur = _ref.onBlur,
      onBlur = _ref$onBlur === void 0 ? function () {} : _ref$onBlur,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$onClear = _ref.onClear,
      onClear = _ref$onClear === void 0 ? function () {} : _ref$onClear,
      _ref$onEnter = _ref.onEnter,
      onEnter = _ref$onEnter === void 0 ? function () {} : _ref$onEnter,
      _ref$onFocus = _ref.onFocus,
      onFocus = _ref$onFocus === void 0 ? function () {} : _ref$onFocus,
      _ref$onSelect = _ref.onSelect,
      onSelect = _ref$onSelect === void 0 ? function () {} : _ref$onSelect,
      _ref$onToggle = _ref.onToggle,
      onToggle = _ref$onToggle === void 0 ? function () {} : _ref$onToggle,
      _ref$refMoleculeAutos = _ref.refMoleculeAutosuggest,
      refMoleculeAutosuggestFromProps = _ref$refMoleculeAutos === void 0 ? {} : _ref$refMoleculeAutos,
      _ref$refMoleculeAutos2 = _ref.refMoleculeAutosuggestInput,
      refMoleculeAutosuggestInputFromProps = _ref$refMoleculeAutos2 === void 0 ? {} : _ref$refMoleculeAutos2,
      state = _ref.state,
      restProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var innerRefMoleculeAutosuggest = useRef();
  var refMoleculeAutosuggest = useMergeRefs(innerRefMoleculeAutosuggest, refMoleculeAutosuggestFromProps);

  var _useState = useState(isOpen),
      isOpenState = _useState[0],
      setOpenState = _useState[1];

  useEffect(function () {
    setOpenState(isOpen);
  }, [isOpen, setOpenState]);
  var refsMoleculeAutosuggestOptions = useRef([]);
  var innerRefMoleculeAutosuggestInput = useRef();
  var refMoleculeAutosuggestInput = useMergeRefs(innerRefMoleculeAutosuggestInput, refMoleculeAutosuggestInputFromProps);

  var _useState2 = useState(false),
      focus = _useState2[0],
      setFocus = _useState2[1];

  var handleToggle = function handleToggle(event, _ref2) {
    var isOpen = _ref2.isOpen;
    setOpenState(isOpen === undefined ? !isOpenState : !!isOpen);
    typeof onToggle === 'function' && onToggle(event, {
      isOpen: isOpen
    });
  };

  var extendedChildren = Children.toArray(children).filter(Boolean).map(function (child, index) {
    refsMoleculeAutosuggestOptions.current[index] = /*#__PURE__*/createRef();
    return /*#__PURE__*/cloneElement(child, {
      innerRef: refsMoleculeAutosuggestOptions.current[index],
      onSelectKey: keysSelection
    });
  });
  var className = cx(BASE_CLASS, errorState && BASE_CLASS + "--" + AUTOSUGGEST_STATES.ERROR, errorState === false && BASE_CLASS + "--" + AUTOSUGGEST_STATES.SUCCESS, state && BASE_CLASS + "--" + state, (_cx = {}, _cx[CLASS_DISABLED] = disabled, _cx));

  var closeList = function closeList(ev) {
    var domMoleculeAutosuggest = innerRefMoleculeAutosuggest.current;
    handleToggle(ev, {
      isOpen: false
    });
    if (multiselection) onChange(ev, {
      value: ''
    });
    domMoleculeAutosuggest && !focus && domMoleculeAutosuggest.focus();
    setFocus(false);
    ev.preventDefault();
    ev.stopPropagation();
  };

  var focusFirstOption = function focusFirstOption(ev, _ref3) {
    var options = _ref3.options;
    if (options[0]) options[0].focus();
    ev.preventDefault();
    ev.stopPropagation();
  };

  var handleKeyDown = function handleKeyDown(ev) {
    ev.persist();
    var domInnerInput = refMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var innerRefInput = innerRefMoleculeAutosuggestInput.current;
    var key = ev.key;
    var options = optionsFromRef.map(getTarget);
    var isTypeableKey = getIsTypeableKey(key);
    var isSelectionKey = keysSelection.includes(key);

    if (isTypeableKey) {
      if (!isSelectionKey) domInnerInput.focus();
    }

    if (isOpenState) {
      var currentElementFocused = getCurrentElementFocused();
      var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
      if (keysCloseList.includes(key)) closeList(ev);else if (key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
        options: options
      });else if (isSomeOptionFocused) handleFocusIn(ev);

      if (key === 'Enter') {
        onEnter(ev);
        innerRefInput && innerRefInput.focus();
      }
    }
  };

  var handleFocusIn = function handleFocusIn(ev) {
    onFocus(ev);
    setFocus(true);
  };

  var handleFocusOut = function handleFocusOut(ev) {
    ev.persist();
    var domContainer = innerRefMoleculeAutosuggest.current;
    var domInnerInput = innerRefMoleculeAutosuggestInput.current;
    var optionsFromRef = refsMoleculeAutosuggestOptions.current;
    var options = optionsFromRef.map(getTarget);
    setTimeout(function () {
      var currentElementFocused = getCurrentElementFocused();
      var focusOutFromOutside = ![domInnerInput].concat(options).includes(currentElementFocused) && !domContainer.contains(currentElementFocused);

      if (focusOutFromOutside) {
        if (autoClose && isOpenState) {
          closeList(ev);
        } else {
          setFocus(false);
          onBlur();
        }
      }
    }, 1);
    setFocus(true);
  };

  var handleInputKeyDown = function handleInputKeyDown(ev) {
    var key = ev.key;
    if (key !== 'ArrowDown') ev.stopPropagation();

    if (key === 'Enter') {
      onEnter(ev);
      onEnter && autoClose && closeList(ev);
    }
  };

  var handleClick = function handleClick() {
    var innerRefInput = innerRefMoleculeAutosuggestInput.current;
    innerRefInput && innerRefInput.focus();
  };

  var autosuggestSelectionProps = _extends({
    autoClose: autoClose,
    children: extendedChildren,
    disabled: disabled,
    errorState: errorState,
    id: id,
    innerRefInput: refMoleculeAutosuggestInput,
    isOpen: isOpenState,
    keysCloseList: keysCloseList,
    keysSelection: keysSelection,
    onBlur: onBlur,
    onChange: onChange,
    onClear: onClear,
    onEnter: onEnter,
    onFocus: onFocus,
    onInputKeyDown: handleInputKeyDown,
    onKeyDown: handleKeyDown,
    onSelect: onSelect,
    onToggle: handleToggle,
    state: state
  }, restProps);

  var AutosuggestSelection = multiselection ? MoleculeAutosuggestMultipleSelection : MoleculeAutosuggestSingleSelection;
  return /*#__PURE__*/_jsx("div", {
    ref: refMoleculeAutosuggest,
    tabIndex: "0",
    className: className,
    onKeyDown: handleKeyDown,
    onFocus: handleFocusIn,
    onBlur: handleFocusOut,
    onClick: handleClick,
    role: "combobox",
    "aria-controls": id,
    "aria-expanded": isOpenState,
    children: /*#__PURE__*/_jsx(AutosuggestSelection, _extends({}, autosuggestSelectionProps))
  });
};

MoleculeAutosuggest.displayName = 'MoleculeAutosuggest';
export default MoleculeAutosuggest;
